Int (imandra-base.Imandra_prelude.Int)

`type t = int`
`val (+) : Z.t -> Z.t -> Z.t`
`val (-) : Z.t -> Z.t -> Z.t`
`val (~-) : Z.t -> Z.t`
`val (*) : Z.t -> Z.t -> Z.t`
`val (/) : Z.t -> Z.t -> Z.t`
`val (mod) : Z.t -> Z.t -> Z.t`
`val (<) : int -> int -> bool`
`val (<=) : int -> int -> bool`
`val (>) : int -> int -> bool`
`val (>=) : int -> int -> bool`
`val min : int -> int -> int`
`val max : int -> int -> int`
`val abs : int -> int`
`val to_string : t -> string`

Conversion to a string. Only works for nonnegative numbers

`val equal : 'a -> 'a -> bool`
`val compare : 'a -> 'a -> int`
`val pp : Stdlib.Format.formatter -> Z.t -> unit`
`val of_caml_int : int -> Z.t`
`val for_ : int -> int -> ( int -> unit ) -> unit`
`val for_down_to : int -> int -> ( int -> unit ) -> unit`